==> huaweicloudsdkeg-3.1.135-py2.py3-none-any.whl: huaweicloudsdkeg/v1/model/put_events_resp_events.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class PutEventsRespEvents:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'error_code': 'str',
        'error_msg': 'str',
        'event_id': 'str'
    }

    attribute_map = {
        'error_code': 'error_code',
        'error_msg': 'error_msg',
        'event_id': 'event_id'
    }

    def __init__(self, error_code=None, error_msg=None, event_id=None):
        """PutEventsRespEvents

        The model defined in huaweicloud sdk

        :param error_code: 发布失败的错误码
        :type error_code: str
        :param error_msg: 发布失败的原因
        :type error_msg: str
        :param event_id: 事件唯一标识串
        :type event_id: str
        """
        
        

        self._error_code = None
        self._error_msg = None
        self._event_id = None
        self.discriminator = None

        if error_code is not None:
            self.error_code = error_code
        if error_msg is not None:
            self.error_msg = error_msg
        if event_id is not None:
            self.event_id = event_id

    @property
    def error_code(self):
        """Gets the error_code of this PutEventsRespEvents.

        发布失败的错误码

        :return: The error_code of this PutEventsRespEvents.
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """Sets the error_code of this PutEventsRespEvents.

        发布失败的错误码

        :param error_code: The error_code of this PutEventsRespEvents.
        :type error_code: str
        """
        self._error_code = error_code

    @property
    def error_msg(self):
        """Gets the error_msg of this PutEventsRespEvents.

        发布失败的原因

        :return: The error_msg of this PutEventsRespEvents.
        :rtype: str
        """
        return self._error_msg

    @error_msg.setter
    def error_msg(self, error_msg):
        """Sets the error_msg of this PutEventsRespEvents.

        发布失败的原因

        :param error_msg: The error_msg of this PutEventsRespEvents.
        :type error_msg: str
        """
        self._error_msg = error_msg

    @property
    def event_id(self):
        """Gets the event_id of this PutEventsRespEvents.

        事件唯一标识串

        :return: The event_id of this PutEventsRespEvents.
        :rtype: str
        """
        return self._event_id

    @event_id.setter
    def event_id(self, event_id):
        """Sets the event_id of this PutEventsRespEvents.

        事件唯一标识串

        :param event_id: The event_id of this PutEventsRespEvents.
        :type event_id: str
        """
        self._event_id = event_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PutEventsRespEvents):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkeg-3.1.148-py2.py3-none-any.whl: huaweicloudsdkeg/v1/model/put_events_resp_events.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class PutEventsRespEvents:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'error_code': 'str',
        'error_msg': 'str',
        'event_id': 'str'
    }

    attribute_map = {
        'error_code': 'error_code',
        'error_msg': 'error_msg',
        'event_id': 'event_id'
    }

    def __init__(self, error_code=None, error_msg=None, event_id=None):
        r"""PutEventsRespEvents

        The model defined in huaweicloud sdk

        :param error_code: 发布失败的错误码
        :type error_code: str
        :param error_msg: 发布失败的原因
        :type error_msg: str
        :param event_id: 事件唯一标识串
        :type event_id: str
        """
        
        

        self._error_code = None
        self._error_msg = None
        self._event_id = None
        self.discriminator = None

        if error_code is not None:
            self.error_code = error_code
        if error_msg is not None:
            self.error_msg = error_msg
        if event_id is not None:
            self.event_id = event_id

    @property
    def error_code(self):
        r"""Gets the error_code of this PutEventsRespEvents.

        发布失败的错误码

        :return: The error_code of this PutEventsRespEvents.
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        r"""Sets the error_code of this PutEventsRespEvents.

        发布失败的错误码

        :param error_code: The error_code of this PutEventsRespEvents.
        :type error_code: str
        """
        self._error_code = error_code

    @property
    def error_msg(self):
        r"""Gets the error_msg of this PutEventsRespEvents.

        发布失败的原因

        :return: The error_msg of this PutEventsRespEvents.
        :rtype: str
        """
        return self._error_msg

    @error_msg.setter
    def error_msg(self, error_msg):
        r"""Sets the error_msg of this PutEventsRespEvents.

        发布失败的原因

        :param error_msg: The error_msg of this PutEventsRespEvents.
        :type error_msg: str
        """
        self._error_msg = error_msg

    @property
    def event_id(self):
        r"""Gets the event_id of this PutEventsRespEvents.

        事件唯一标识串

        :return: The event_id of this PutEventsRespEvents.
        :rtype: str
        """
        return self._event_id

    @event_id.setter
    def event_id(self, event_id):
        r"""Sets the event_id of this PutEventsRespEvents.

        事件唯一标识串

        :param event_id: The event_id of this PutEventsRespEvents.
        :type event_id: str
        """
        self._event_id = event_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PutEventsRespEvents):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
